pub struct ExternalReaderRuntime { /* private fields */ }Implementations
Sourceimpl ExternalReaderRuntime
impl ExternalReaderRuntime
pub fn new() -> Self
Sourcepub fn add_resource_readers<T: IntoResourceReaders>(
&mut self,
readers: T,
) -> &mut Self
pub fn add_resource_readers<T: IntoResourceReaders>( &mut self, readers: T, ) -> &mut Self
Add a single, or tuple of resource readers to the client.
Panics if any of the readers have the same scheme.
pub fn add_module_readers<T: IntoModuleReaders>( &mut self, readers: T, ) -> &mut Self
pub fn run(&self) -> Result<(), Box<dyn Error>>